| df.type | R Documentation |
Function to check the type of dataframe in relation to fishRman. Most of the times the user will not call this function directly, but it can be useful for debug.
df.type(df)
df |
The dataframe to check. |
A string explaining how the input dataframe is treated by fishRman.
dated <- c("2020-01-01", "2020-01-02")
lat <- c(40, 41)
lon <- c(12,13)
mmsi <- c("34534555", "25634555")
hours <- c(0, 5)
fishing_hours <- c(1,9)
df <- data.frame(dated, lat, lon, mmsi, hours, fishing_hours)
what.type <- df.type(df)
print(what.type)
# "GFW Fishing Effort By Vessel"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.